mapping

package
v0.10.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 23, 2026 License: AGPL-3.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func FromPbLanguage

func FromPbLanguage(lang commonv1.Language) entity.Language

func SnapshotToPbWord added in v0.10.0

func SnapshotToPbWord(snapshot *entity.LemmaSnapshot, queriedTerm string) *dictv1.Word

SnapshotToPbWord converts a LemmaSnapshot to dictv1.Word. queriedTerm: the user's query term (may be lemma or inflected form).

func ToEntityWordStatsFilter added in v0.3.0

func ToEntityWordStatsFilter(req *dictv1.GetWordStatsRequest) *entity.WordStatsFilter

ToEntityWordStatsFilter converts a protobuf request into a domain filter.

func ToPbError

func ToPbError(err error) error

func ToPbLanguage

func ToPbLanguage(lang entity.Language) commonv1.Language

func ToPbWord

func ToPbWord(entry *entity.WordEntry) *dictv1.Word

ToPbWord converts a word entry into the public proto response.

func ToPbWordStats added in v0.3.0

func ToPbWordStats(stats *entity.WordStats) *dictv1.GetWordStatsResponse

ToPbWordStats maps a domain stats struct back to the protobuf response.

Types

This section is empty.

Jump to