pipelinev1

package
v0.10.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 9, 2026 License: AGPL-3.0 Imports: 20 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	PipelineStatus_name = map[int32]string{
		0: "PIPELINE_STATUS_UNSPECIFIED",
		1: "PIPELINE_STATUS_PENDING",
		2: "PIPELINE_STATUS_RUNNING",
		3: "PIPELINE_STATUS_PAUSED",
		4: "PIPELINE_STATUS_COMPLETED",
		5: "PIPELINE_STATUS_FAILED",
		6: "PIPELINE_STATUS_CANCELLED",
		7: "PIPELINE_STATUS_SKIPPED",
	}
	PipelineStatus_value = map[string]int32{
		"PIPELINE_STATUS_UNSPECIFIED": 0,
		"PIPELINE_STATUS_PENDING":     1,
		"PIPELINE_STATUS_RUNNING":     2,
		"PIPELINE_STATUS_PAUSED":      3,
		"PIPELINE_STATUS_COMPLETED":   4,
		"PIPELINE_STATUS_FAILED":      5,
		"PIPELINE_STATUS_CANCELLED":   6,
		"PIPELINE_STATUS_SKIPPED":     7,
	}
)

Enum value maps for PipelineStatus.

var (
	PipelinePhase_name = map[int32]string{
		0: "PIPELINE_PHASE_UNSPECIFIED",
		1: "PIPELINE_PHASE_COLLECTION",
		2: "PIPELINE_PHASE_EVALUATION",
		3: "PIPELINE_PHASE_INTEGRATION",
		4: "PIPELINE_PHASE_SNAPSHOT",
	}
	PipelinePhase_value = map[string]int32{
		"PIPELINE_PHASE_UNSPECIFIED": 0,
		"PIPELINE_PHASE_COLLECTION":  1,
		"PIPELINE_PHASE_EVALUATION":  2,
		"PIPELINE_PHASE_INTEGRATION": 3,
		"PIPELINE_PHASE_SNAPSHOT":    4,
	}
)

Enum value maps for PipelinePhase.

var (
	PipelineActionType_name = map[int32]string{
		0: "PIPELINE_ACTION_TYPE_UNSPECIFIED",
		1: "PIPELINE_ACTION_TYPE_CANCEL",
		2: "PIPELINE_ACTION_TYPE_RENEW",
	}
	PipelineActionType_value = map[string]int32{
		"PIPELINE_ACTION_TYPE_UNSPECIFIED": 0,
		"PIPELINE_ACTION_TYPE_CANCEL":      1,
		"PIPELINE_ACTION_TYPE_RENEW":       2,
	}
)

Enum value maps for PipelineActionType.

var File_pipeline_v1_pipeline_proto protoreflect.FileDescriptor
var File_pipeline_v1_pipeline_service_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type ActionJobRequest

type ActionJobRequest struct {
	JobId  int64              `protobuf:"varint,1,opt,name=job_id,json=jobId,proto3" json:"job_id,omitempty"`
	Action PipelineActionType `protobuf:"varint,2,opt,name=action,proto3,enum=pipeline.v1.PipelineActionType" json:"action,omitempty"`
	// contains filtered or unexported fields
}

func (*ActionJobRequest) Descriptor deprecated

func (*ActionJobRequest) Descriptor() ([]byte, []int)

Deprecated: Use ActionJobRequest.ProtoReflect.Descriptor instead.

func (*ActionJobRequest) GetAction

func (x *ActionJobRequest) GetAction() PipelineActionType

func (*ActionJobRequest) GetJobId

func (x *ActionJobRequest) GetJobId() int64

func (*ActionJobRequest) ProtoMessage

func (*ActionJobRequest) ProtoMessage()

func (*ActionJobRequest) ProtoReflect

func (x *ActionJobRequest) ProtoReflect() protoreflect.Message

func (*ActionJobRequest) Reset

func (x *ActionJobRequest) Reset()

func (*ActionJobRequest) String

func (x *ActionJobRequest) String() string

func (*ActionJobRequest) Validate

func (m *ActionJobRequest) Validate() error

Validate checks the field values on ActionJobRequest with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.

func (*ActionJobRequest) ValidateAll

func (m *ActionJobRequest) ValidateAll() error

ValidateAll checks the field values on ActionJobRequest with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in ActionJobRequestMultiError, or nil if none found.

type ActionJobRequestMultiError

type ActionJobRequestMultiError []error

ActionJobRequestMultiError is an error wrapping multiple validation errors returned by ActionJobRequest.ValidateAll() if the designated constraints aren't met.

func (ActionJobRequestMultiError) AllErrors

func (m ActionJobRequestMultiError) AllErrors() []error

AllErrors returns a list of validation violation errors.

func (ActionJobRequestMultiError) Error

Error returns a concatenation of all the error messages it wraps.

type ActionJobRequestValidationError

type ActionJobRequestValidationError struct {
	// contains filtered or unexported fields
}

ActionJobRequestValidationError is the validation error returned by ActionJobRequest.Validate if the designated constraints aren't met.

func (ActionJobRequestValidationError) Cause

Cause function returns cause value.

func (ActionJobRequestValidationError) Error

Error satisfies the builtin error interface

func (ActionJobRequestValidationError) ErrorName

ErrorName returns error name.

func (ActionJobRequestValidationError) Field

Field function returns field value.

func (ActionJobRequestValidationError) Key

Key function returns key value.

func (ActionJobRequestValidationError) Reason

Reason function returns reason value.

type ActionJobResponse

type ActionJobResponse struct {

	// For cancel action, this is the updated job.
	Job *PipelineJob `protobuf:"bytes,1,opt,name=job,proto3" json:"job,omitempty"`
	// For renew action, this is the newly created job.
	NewJob *PipelineJob `protobuf:"bytes,2,opt,name=new_job,json=newJob,proto3" json:"new_job,omitempty"`
	// contains filtered or unexported fields
}

func (*ActionJobResponse) Descriptor deprecated

func (*ActionJobResponse) Descriptor() ([]byte, []int)

Deprecated: Use ActionJobResponse.ProtoReflect.Descriptor instead.

func (*ActionJobResponse) GetJob

func (x *ActionJobResponse) GetJob() *PipelineJob

func (*ActionJobResponse) GetNewJob

func (x *ActionJobResponse) GetNewJob() *PipelineJob

func (*ActionJobResponse) ProtoMessage

func (*ActionJobResponse) ProtoMessage()

func (*ActionJobResponse) ProtoReflect

func (x *ActionJobResponse) ProtoReflect() protoreflect.Message

func (*ActionJobResponse) Reset

func (x *ActionJobResponse) Reset()

func (*ActionJobResponse) String

func (x *ActionJobResponse) String() string

func (*ActionJobResponse) Validate

func (m *ActionJobResponse) Validate() error

Validate checks the field values on ActionJobResponse with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.

func (*ActionJobResponse) ValidateAll

func (m *ActionJobResponse) ValidateAll() error

ValidateAll checks the field values on ActionJobResponse with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in ActionJobResponseMultiError, or nil if none found.

type ActionJobResponseMultiError

type ActionJobResponseMultiError []error

ActionJobResponseMultiError is an error wrapping multiple validation errors returned by ActionJobResponse.ValidateAll() if the designated constraints aren't met.

func (ActionJobResponseMultiError) AllErrors

func (m ActionJobResponseMultiError) AllErrors() []error

AllErrors returns a list of validation violation errors.

func (ActionJobResponseMultiError) Error

Error returns a concatenation of all the error messages it wraps.

type ActionJobResponseValidationError

type ActionJobResponseValidationError struct {
	// contains filtered or unexported fields
}

ActionJobResponseValidationError is the validation error returned by ActionJobResponse.Validate if the designated constraints aren't met.

func (ActionJobResponseValidationError) Cause

Cause function returns cause value.

func (ActionJobResponseValidationError) Error

Error satisfies the builtin error interface

func (ActionJobResponseValidationError) ErrorName

ErrorName returns error name.

func (ActionJobResponseValidationError) Field

Field function returns field value.

func (ActionJobResponseValidationError) Key

Key function returns key value.

func (ActionJobResponseValidationError) Reason

Reason function returns reason value.

type ListJobStagesRequest

type ListJobStagesRequest struct {
	JobId int64 `protobuf:"varint,1,opt,name=job_id,json=jobId,proto3" json:"job_id,omitempty"`
	// contains filtered or unexported fields
}

func (*ListJobStagesRequest) Descriptor deprecated

func (*ListJobStagesRequest) Descriptor() ([]byte, []int)

Deprecated: Use ListJobStagesRequest.ProtoReflect.Descriptor instead.

func (*ListJobStagesRequest) GetJobId

func (x *ListJobStagesRequest) GetJobId() int64

func (*ListJobStagesRequest) ProtoMessage

func (*ListJobStagesRequest) ProtoMessage()

func (*ListJobStagesRequest) ProtoReflect

func (x *ListJobStagesRequest) ProtoReflect() protoreflect.Message

func (*ListJobStagesRequest) Reset

func (x *ListJobStagesRequest) Reset()

func (*ListJobStagesRequest) String

func (x *ListJobStagesRequest) String() string

func (*ListJobStagesRequest) Validate

func (m *ListJobStagesRequest) Validate() error

Validate checks the field values on ListJobStagesRequest with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.

func (*ListJobStagesRequest) ValidateAll

func (m *ListJobStagesRequest) ValidateAll() error

ValidateAll checks the field values on ListJobStagesRequest with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in ListJobStagesRequestMultiError, or nil if none found.

type ListJobStagesRequestMultiError

type ListJobStagesRequestMultiError []error

ListJobStagesRequestMultiError is an error wrapping multiple validation errors returned by ListJobStagesRequest.ValidateAll() if the designated constraints aren't met.

func (ListJobStagesRequestMultiError) AllErrors

func (m ListJobStagesRequestMultiError) AllErrors() []error

AllErrors returns a list of validation violation errors.

func (ListJobStagesRequestMultiError) Error

Error returns a concatenation of all the error messages it wraps.

type ListJobStagesRequestValidationError

type ListJobStagesRequestValidationError struct {
	// contains filtered or unexported fields
}

ListJobStagesRequestValidationError is the validation error returned by ListJobStagesRequest.Validate if the designated constraints aren't met.

func (ListJobStagesRequestValidationError) Cause

Cause function returns cause value.

func (ListJobStagesRequestValidationError) Error

Error satisfies the builtin error interface

func (ListJobStagesRequestValidationError) ErrorName

ErrorName returns error name.

func (ListJobStagesRequestValidationError) Field

Field function returns field value.

func (ListJobStagesRequestValidationError) Key

Key function returns key value.

func (ListJobStagesRequestValidationError) Reason

Reason function returns reason value.

type ListJobStagesResponse

type ListJobStagesResponse struct {
	Stages []*PipelineStage `protobuf:"bytes,1,rep,name=stages,proto3" json:"stages,omitempty"`
	// contains filtered or unexported fields
}

func (*ListJobStagesResponse) Descriptor deprecated

func (*ListJobStagesResponse) Descriptor() ([]byte, []int)

Deprecated: Use ListJobStagesResponse.ProtoReflect.Descriptor instead.

func (*ListJobStagesResponse) GetStages

func (x *ListJobStagesResponse) GetStages() []*PipelineStage

func (*ListJobStagesResponse) ProtoMessage

func (*ListJobStagesResponse) ProtoMessage()

func (*ListJobStagesResponse) ProtoReflect

func (x *ListJobStagesResponse) ProtoReflect() protoreflect.Message

func (*ListJobStagesResponse) Reset

func (x *ListJobStagesResponse) Reset()

func (*ListJobStagesResponse) String

func (x *ListJobStagesResponse) String() string

func (*ListJobStagesResponse) Validate

func (m *ListJobStagesResponse) Validate() error

Validate checks the field values on ListJobStagesResponse with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.

func (*ListJobStagesResponse) ValidateAll

func (m *ListJobStagesResponse) ValidateAll() error

ValidateAll checks the field values on ListJobStagesResponse with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in ListJobStagesResponseMultiError, or nil if none found.

type ListJobStagesResponseMultiError

type ListJobStagesResponseMultiError []error

ListJobStagesResponseMultiError is an error wrapping multiple validation errors returned by ListJobStagesResponse.ValidateAll() if the designated constraints aren't met.

func (ListJobStagesResponseMultiError) AllErrors

func (m ListJobStagesResponseMultiError) AllErrors() []error

AllErrors returns a list of validation violation errors.

func (ListJobStagesResponseMultiError) Error

Error returns a concatenation of all the error messages it wraps.

type ListJobStagesResponseValidationError

type ListJobStagesResponseValidationError struct {
	// contains filtered or unexported fields
}

ListJobStagesResponseValidationError is the validation error returned by ListJobStagesResponse.Validate if the designated constraints aren't met.

func (ListJobStagesResponseValidationError) Cause

Cause function returns cause value.

func (ListJobStagesResponseValidationError) Error

Error satisfies the builtin error interface

func (ListJobStagesResponseValidationError) ErrorName

ErrorName returns error name.

func (ListJobStagesResponseValidationError) Field

Field function returns field value.

func (ListJobStagesResponseValidationError) Key

Key function returns key value.

func (ListJobStagesResponseValidationError) Reason

Reason function returns reason value.

type ListJobsRequest

type ListJobsRequest struct {
	Pagination *v1.PaginationRequest `protobuf:"bytes,1,opt,name=pagination,proto3" json:"pagination,omitempty"`
	// Optional filter. UNSPECIFIED means no status filter.
	Status PipelineStatus `protobuf:"varint,2,opt,name=status,proto3,enum=pipeline.v1.PipelineStatus" json:"status,omitempty"`
	// Optional filter by lemma ID.
	LemmaId int64 `protobuf:"varint,3,opt,name=lemma_id,json=lemmaId,proto3" json:"lemma_id,omitempty"`
	// contains filtered or unexported fields
}

func (*ListJobsRequest) Descriptor deprecated

func (*ListJobsRequest) Descriptor() ([]byte, []int)

Deprecated: Use ListJobsRequest.ProtoReflect.Descriptor instead.

func (*ListJobsRequest) GetLemmaId

func (x *ListJobsRequest) GetLemmaId() int64

func (*ListJobsRequest) GetPagination

func (x *ListJobsRequest) GetPagination() *v1.PaginationRequest

func (*ListJobsRequest) GetStatus

func (x *ListJobsRequest) GetStatus() PipelineStatus

func (*ListJobsRequest) ProtoMessage

func (*ListJobsRequest) ProtoMessage()

func (*ListJobsRequest) ProtoReflect

func (x *ListJobsRequest) ProtoReflect() protoreflect.Message

func (*ListJobsRequest) Reset

func (x *ListJobsRequest) Reset()

func (*ListJobsRequest) String

func (x *ListJobsRequest) String() string

func (*ListJobsRequest) Validate

func (m *ListJobsRequest) Validate() error

Validate checks the field values on ListJobsRequest with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.

func (*ListJobsRequest) ValidateAll

func (m *ListJobsRequest) ValidateAll() error

ValidateAll checks the field values on ListJobsRequest with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in ListJobsRequestMultiError, or nil if none found.

type ListJobsRequestMultiError

type ListJobsRequestMultiError []error

ListJobsRequestMultiError is an error wrapping multiple validation errors returned by ListJobsRequest.ValidateAll() if the designated constraints aren't met.

func (ListJobsRequestMultiError) AllErrors

func (m ListJobsRequestMultiError) AllErrors() []error

AllErrors returns a list of validation violation errors.

func (ListJobsRequestMultiError) Error

Error returns a concatenation of all the error messages it wraps.

type ListJobsRequestValidationError

type ListJobsRequestValidationError struct {
	// contains filtered or unexported fields
}

ListJobsRequestValidationError is the validation error returned by ListJobsRequest.Validate if the designated constraints aren't met.

func (ListJobsRequestValidationError) Cause

Cause function returns cause value.

func (ListJobsRequestValidationError) Error

Error satisfies the builtin error interface

func (ListJobsRequestValidationError) ErrorName

func (e ListJobsRequestValidationError) ErrorName() string

ErrorName returns error name.

func (ListJobsRequestValidationError) Field

Field function returns field value.

func (ListJobsRequestValidationError) Key

Key function returns key value.

func (ListJobsRequestValidationError) Reason

Reason function returns reason value.

type ListJobsResponse

type ListJobsResponse struct {
	Jobs       []*PipelineJob         `protobuf:"bytes,1,rep,name=jobs,proto3" json:"jobs,omitempty"`
	Pagination *v1.PaginationResponse `protobuf:"bytes,2,opt,name=pagination,proto3" json:"pagination,omitempty"`
	// contains filtered or unexported fields
}

func (*ListJobsResponse) Descriptor deprecated

func (*ListJobsResponse) Descriptor() ([]byte, []int)

Deprecated: Use ListJobsResponse.ProtoReflect.Descriptor instead.

func (*ListJobsResponse) GetJobs

func (x *ListJobsResponse) GetJobs() []*PipelineJob

func (*ListJobsResponse) GetPagination

func (x *ListJobsResponse) GetPagination() *v1.PaginationResponse

func (*ListJobsResponse) ProtoMessage

func (*ListJobsResponse) ProtoMessage()

func (*ListJobsResponse) ProtoReflect

func (x *ListJobsResponse) ProtoReflect() protoreflect.Message

func (*ListJobsResponse) Reset

func (x *ListJobsResponse) Reset()

func (*ListJobsResponse) String

func (x *ListJobsResponse) String() string

func (*ListJobsResponse) Validate

func (m *ListJobsResponse) Validate() error

Validate checks the field values on ListJobsResponse with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.

func (*ListJobsResponse) ValidateAll

func (m *ListJobsResponse) ValidateAll() error

ValidateAll checks the field values on ListJobsResponse with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in ListJobsResponseMultiError, or nil if none found.

type ListJobsResponseMultiError

type ListJobsResponseMultiError []error

ListJobsResponseMultiError is an error wrapping multiple validation errors returned by ListJobsResponse.ValidateAll() if the designated constraints aren't met.

func (ListJobsResponseMultiError) AllErrors

func (m ListJobsResponseMultiError) AllErrors() []error

AllErrors returns a list of validation violation errors.

func (ListJobsResponseMultiError) Error

Error returns a concatenation of all the error messages it wraps.

type ListJobsResponseValidationError

type ListJobsResponseValidationError struct {
	// contains filtered or unexported fields
}

ListJobsResponseValidationError is the validation error returned by ListJobsResponse.Validate if the designated constraints aren't met.

func (ListJobsResponseValidationError) Cause

Cause function returns cause value.

func (ListJobsResponseValidationError) Error

Error satisfies the builtin error interface

func (ListJobsResponseValidationError) ErrorName

ErrorName returns error name.

func (ListJobsResponseValidationError) Field

Field function returns field value.

func (ListJobsResponseValidationError) Key

Key function returns key value.

func (ListJobsResponseValidationError) Reason

Reason function returns reason value.

type PipelineActionType

type PipelineActionType int32
const (
	PipelineActionType_PIPELINE_ACTION_TYPE_UNSPECIFIED PipelineActionType = 0
	PipelineActionType_PIPELINE_ACTION_TYPE_CANCEL      PipelineActionType = 1
	// Renew creates a new pipeline run/job; it does not mutate stage execution of old job.
	PipelineActionType_PIPELINE_ACTION_TYPE_RENEW PipelineActionType = 2
)

func (PipelineActionType) Descriptor

func (PipelineActionType) Enum

func (PipelineActionType) EnumDescriptor deprecated

func (PipelineActionType) EnumDescriptor() ([]byte, []int)

Deprecated: Use PipelineActionType.Descriptor instead.

func (PipelineActionType) Number

func (PipelineActionType) String

func (x PipelineActionType) String() string

func (PipelineActionType) Type

type PipelineJob

type PipelineJob struct {
	Id           int64                  `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
	Status       PipelineStatus         `protobuf:"varint,2,opt,name=status,proto3,enum=pipeline.v1.PipelineStatus" json:"status,omitempty"`
	Name         string                 `protobuf:"bytes,3,opt,name=name,proto3" json:"name,omitempty"`
	Language     string                 `protobuf:"bytes,4,opt,name=language,proto3" json:"language,omitempty"`
	Tier         int32                  `protobuf:"varint,5,opt,name=tier,proto3" json:"tier,omitempty"`
	Term         string                 `protobuf:"bytes,6,opt,name=term,proto3" json:"term,omitempty"`
	ErrorMessage string                 `protobuf:"bytes,7,opt,name=error_message,json=errorMessage,proto3" json:"error_message,omitempty"`
	StartedAt    *timestamppb.Timestamp `protobuf:"bytes,8,opt,name=started_at,json=startedAt,proto3" json:"started_at,omitempty"`
	CompletedAt  *timestamppb.Timestamp `protobuf:"bytes,9,opt,name=completed_at,json=completedAt,proto3" json:"completed_at,omitempty"`
	CreatedAt    *timestamppb.Timestamp `protobuf:"bytes,10,opt,name=created_at,json=createdAt,proto3" json:"created_at,omitempty"`
	UpdatedAt    *timestamppb.Timestamp `protobuf:"bytes,11,opt,name=updated_at,json=updatedAt,proto3" json:"updated_at,omitempty"`
	// contains filtered or unexported fields
}

func (*PipelineJob) Descriptor deprecated

func (*PipelineJob) Descriptor() ([]byte, []int)

Deprecated: Use PipelineJob.ProtoReflect.Descriptor instead.

func (*PipelineJob) GetCompletedAt

func (x *PipelineJob) GetCompletedAt() *timestamppb.Timestamp

func (*PipelineJob) GetCreatedAt

func (x *PipelineJob) GetCreatedAt() *timestamppb.Timestamp

func (*PipelineJob) GetErrorMessage

func (x *PipelineJob) GetErrorMessage() string

func (*PipelineJob) GetId

func (x *PipelineJob) GetId() int64

func (*PipelineJob) GetLanguage

func (x *PipelineJob) GetLanguage() string

func (*PipelineJob) GetName

func (x *PipelineJob) GetName() string

func (*PipelineJob) GetStartedAt

func (x *PipelineJob) GetStartedAt() *timestamppb.Timestamp

func (*PipelineJob) GetStatus

func (x *PipelineJob) GetStatus() PipelineStatus

func (*PipelineJob) GetTerm

func (x *PipelineJob) GetTerm() string

func (*PipelineJob) GetTier

func (x *PipelineJob) GetTier() int32

func (*PipelineJob) GetUpdatedAt

func (x *PipelineJob) GetUpdatedAt() *timestamppb.Timestamp

func (*PipelineJob) ProtoMessage

func (*PipelineJob) ProtoMessage()

func (*PipelineJob) ProtoReflect

func (x *PipelineJob) ProtoReflect() protoreflect.Message

func (*PipelineJob) Reset

func (x *PipelineJob) Reset()

func (*PipelineJob) String

func (x *PipelineJob) String() string

func (*PipelineJob) Validate

func (m *PipelineJob) Validate() error

Validate checks the field values on PipelineJob with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.

func (*PipelineJob) ValidateAll

func (m *PipelineJob) ValidateAll() error

ValidateAll checks the field values on PipelineJob with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in PipelineJobMultiError, or nil if none found.

type PipelineJobMultiError

type PipelineJobMultiError []error

PipelineJobMultiError is an error wrapping multiple validation errors returned by PipelineJob.ValidateAll() if the designated constraints aren't met.

func (PipelineJobMultiError) AllErrors

func (m PipelineJobMultiError) AllErrors() []error

AllErrors returns a list of validation violation errors.

func (PipelineJobMultiError) Error

func (m PipelineJobMultiError) Error() string

Error returns a concatenation of all the error messages it wraps.

type PipelineJobValidationError

type PipelineJobValidationError struct {
	// contains filtered or unexported fields
}

PipelineJobValidationError is the validation error returned by PipelineJob.Validate if the designated constraints aren't met.

func (PipelineJobValidationError) Cause

Cause function returns cause value.

func (PipelineJobValidationError) Error

Error satisfies the builtin error interface

func (PipelineJobValidationError) ErrorName

func (e PipelineJobValidationError) ErrorName() string

ErrorName returns error name.

func (PipelineJobValidationError) Field

Field function returns field value.

func (PipelineJobValidationError) Key

Key function returns key value.

func (PipelineJobValidationError) Reason

Reason function returns reason value.

type PipelinePhase

type PipelinePhase int32
const (
	PipelinePhase_PIPELINE_PHASE_UNSPECIFIED PipelinePhase = 0
	PipelinePhase_PIPELINE_PHASE_COLLECTION  PipelinePhase = 1
	PipelinePhase_PIPELINE_PHASE_EVALUATION  PipelinePhase = 2
	PipelinePhase_PIPELINE_PHASE_INTEGRATION PipelinePhase = 3
	PipelinePhase_PIPELINE_PHASE_SNAPSHOT    PipelinePhase = 4
)

func (PipelinePhase) Descriptor

func (PipelinePhase) Enum

func (x PipelinePhase) Enum() *PipelinePhase

func (PipelinePhase) EnumDescriptor deprecated

func (PipelinePhase) EnumDescriptor() ([]byte, []int)

Deprecated: Use PipelinePhase.Descriptor instead.

func (PipelinePhase) Number

func (PipelinePhase) String

func (x PipelinePhase) String() string

func (PipelinePhase) Type

type PipelineStage

type PipelineStage struct {
	Id           int64                  `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
	JobId        int64                  `protobuf:"varint,2,opt,name=job_id,json=jobId,proto3" json:"job_id,omitempty"`
	LemmaId      int64                  `protobuf:"varint,3,opt,name=lemma_id,json=lemmaId,proto3" json:"lemma_id,omitempty"`
	Phase        PipelinePhase          `protobuf:"varint,4,opt,name=phase,proto3,enum=pipeline.v1.PipelinePhase" json:"phase,omitempty"`
	Status       PipelineStatus         `protobuf:"varint,5,opt,name=status,proto3,enum=pipeline.v1.PipelineStatus" json:"status,omitempty"`
	Attempts     int32                  `protobuf:"varint,6,opt,name=attempts,proto3" json:"attempts,omitempty"`
	ErrorMessage string                 `protobuf:"bytes,7,opt,name=error_message,json=errorMessage,proto3" json:"error_message,omitempty"`
	StartedAt    *timestamppb.Timestamp `protobuf:"bytes,8,opt,name=started_at,json=startedAt,proto3" json:"started_at,omitempty"`
	CompletedAt  *timestamppb.Timestamp `protobuf:"bytes,9,opt,name=completed_at,json=completedAt,proto3" json:"completed_at,omitempty"`
	CreatedAt    *timestamppb.Timestamp `protobuf:"bytes,10,opt,name=created_at,json=createdAt,proto3" json:"created_at,omitempty"`
	UpdatedAt    *timestamppb.Timestamp `protobuf:"bytes,11,opt,name=updated_at,json=updatedAt,proto3" json:"updated_at,omitempty"`
	// contains filtered or unexported fields
}

func (*PipelineStage) Descriptor deprecated

func (*PipelineStage) Descriptor() ([]byte, []int)

Deprecated: Use PipelineStage.ProtoReflect.Descriptor instead.

func (*PipelineStage) GetAttempts

func (x *PipelineStage) GetAttempts() int32

func (*PipelineStage) GetCompletedAt

func (x *PipelineStage) GetCompletedAt() *timestamppb.Timestamp

func (*PipelineStage) GetCreatedAt

func (x *PipelineStage) GetCreatedAt() *timestamppb.Timestamp

func (*PipelineStage) GetErrorMessage

func (x *PipelineStage) GetErrorMessage() string

func (*PipelineStage) GetId

func (x *PipelineStage) GetId() int64

func (*PipelineStage) GetJobId

func (x *PipelineStage) GetJobId() int64

func (*PipelineStage) GetLemmaId

func (x *PipelineStage) GetLemmaId() int64

func (*PipelineStage) GetPhase

func (x *PipelineStage) GetPhase() PipelinePhase

func (*PipelineStage) GetStartedAt

func (x *PipelineStage) GetStartedAt() *timestamppb.Timestamp

func (*PipelineStage) GetStatus

func (x *PipelineStage) GetStatus() PipelineStatus

func (*PipelineStage) GetUpdatedAt

func (x *PipelineStage) GetUpdatedAt() *timestamppb.Timestamp

func (*PipelineStage) ProtoMessage

func (*PipelineStage) ProtoMessage()

func (*PipelineStage) ProtoReflect

func (x *PipelineStage) ProtoReflect() protoreflect.Message

func (*PipelineStage) Reset

func (x *PipelineStage) Reset()

func (*PipelineStage) String

func (x *PipelineStage) String() string

func (*PipelineStage) Validate

func (m *PipelineStage) Validate() error

Validate checks the field values on PipelineStage with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.

func (*PipelineStage) ValidateAll

func (m *PipelineStage) ValidateAll() error

ValidateAll checks the field values on PipelineStage with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in PipelineStageMultiError, or nil if none found.

type PipelineStageMultiError

type PipelineStageMultiError []error

PipelineStageMultiError is an error wrapping multiple validation errors returned by PipelineStage.ValidateAll() if the designated constraints aren't met.

func (PipelineStageMultiError) AllErrors

func (m PipelineStageMultiError) AllErrors() []error

AllErrors returns a list of validation violation errors.

func (PipelineStageMultiError) Error

func (m PipelineStageMultiError) Error() string

Error returns a concatenation of all the error messages it wraps.

type PipelineStageValidationError

type PipelineStageValidationError struct {
	// contains filtered or unexported fields
}

PipelineStageValidationError is the validation error returned by PipelineStage.Validate if the designated constraints aren't met.

func (PipelineStageValidationError) Cause

Cause function returns cause value.

func (PipelineStageValidationError) Error

Error satisfies the builtin error interface

func (PipelineStageValidationError) ErrorName

func (e PipelineStageValidationError) ErrorName() string

ErrorName returns error name.

func (PipelineStageValidationError) Field

Field function returns field value.

func (PipelineStageValidationError) Key

Key function returns key value.

func (PipelineStageValidationError) Reason

Reason function returns reason value.

type PipelineStatus

type PipelineStatus int32
const (
	PipelineStatus_PIPELINE_STATUS_UNSPECIFIED PipelineStatus = 0
	PipelineStatus_PIPELINE_STATUS_PENDING     PipelineStatus = 1
	PipelineStatus_PIPELINE_STATUS_RUNNING     PipelineStatus = 2
	PipelineStatus_PIPELINE_STATUS_PAUSED      PipelineStatus = 3
	PipelineStatus_PIPELINE_STATUS_COMPLETED   PipelineStatus = 4
	PipelineStatus_PIPELINE_STATUS_FAILED      PipelineStatus = 5
	PipelineStatus_PIPELINE_STATUS_CANCELLED   PipelineStatus = 6
	PipelineStatus_PIPELINE_STATUS_SKIPPED     PipelineStatus = 7
)

func (PipelineStatus) Descriptor

func (PipelineStatus) Enum

func (x PipelineStatus) Enum() *PipelineStatus

func (PipelineStatus) EnumDescriptor deprecated

func (PipelineStatus) EnumDescriptor() ([]byte, []int)

Deprecated: Use PipelineStatus.Descriptor instead.

func (PipelineStatus) Number

func (PipelineStatus) String

func (x PipelineStatus) String() string

func (PipelineStatus) Type

type SubmitJobRequest

type SubmitJobRequest struct {
	Term     string `protobuf:"bytes,1,opt,name=term,proto3" json:"term,omitempty"`
	Language string `protobuf:"bytes,2,opt,name=language,proto3" json:"language,omitempty"`
	Tier     int32  `protobuf:"varint,3,opt,name=tier,proto3" json:"tier,omitempty"`
	Name     string `protobuf:"bytes,4,opt,name=name,proto3" json:"name,omitempty"`
	// contains filtered or unexported fields
}

func (*SubmitJobRequest) Descriptor deprecated

func (*SubmitJobRequest) Descriptor() ([]byte, []int)

Deprecated: Use SubmitJobRequest.ProtoReflect.Descriptor instead.

func (*SubmitJobRequest) GetLanguage

func (x *SubmitJobRequest) GetLanguage() string

func (*SubmitJobRequest) GetName

func (x *SubmitJobRequest) GetName() string

func (*SubmitJobRequest) GetTerm

func (x *SubmitJobRequest) GetTerm() string

func (*SubmitJobRequest) GetTier

func (x *SubmitJobRequest) GetTier() int32

func (*SubmitJobRequest) ProtoMessage

func (*SubmitJobRequest) ProtoMessage()

func (*SubmitJobRequest) ProtoReflect

func (x *SubmitJobRequest) ProtoReflect() protoreflect.Message

func (*SubmitJobRequest) Reset

func (x *SubmitJobRequest) Reset()

func (*SubmitJobRequest) String

func (x *SubmitJobRequest) String() string

func (*SubmitJobRequest) Validate

func (m *SubmitJobRequest) Validate() error

Validate checks the field values on SubmitJobRequest with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.

func (*SubmitJobRequest) ValidateAll

func (m *SubmitJobRequest) ValidateAll() error

ValidateAll checks the field values on SubmitJobRequest with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in SubmitJobRequestMultiError, or nil if none found.

type SubmitJobRequestMultiError

type SubmitJobRequestMultiError []error

SubmitJobRequestMultiError is an error wrapping multiple validation errors returned by SubmitJobRequest.ValidateAll() if the designated constraints aren't met.

func (SubmitJobRequestMultiError) AllErrors

func (m SubmitJobRequestMultiError) AllErrors() []error

AllErrors returns a list of validation violation errors.

func (SubmitJobRequestMultiError) Error

Error returns a concatenation of all the error messages it wraps.

type SubmitJobRequestValidationError

type SubmitJobRequestValidationError struct {
	// contains filtered or unexported fields
}

SubmitJobRequestValidationError is the validation error returned by SubmitJobRequest.Validate if the designated constraints aren't met.

func (SubmitJobRequestValidationError) Cause

Cause function returns cause value.

func (SubmitJobRequestValidationError) Error

Error satisfies the builtin error interface

func (SubmitJobRequestValidationError) ErrorName

ErrorName returns error name.

func (SubmitJobRequestValidationError) Field

Field function returns field value.

func (SubmitJobRequestValidationError) Key

Key function returns key value.

func (SubmitJobRequestValidationError) Reason

Reason function returns reason value.

type SubmitJobResponse

type SubmitJobResponse struct {
	Job *PipelineJob `protobuf:"bytes,1,opt,name=job,proto3" json:"job,omitempty"`
	// contains filtered or unexported fields
}

func (*SubmitJobResponse) Descriptor deprecated

func (*SubmitJobResponse) Descriptor() ([]byte, []int)

Deprecated: Use SubmitJobResponse.ProtoReflect.Descriptor instead.

func (*SubmitJobResponse) GetJob

func (x *SubmitJobResponse) GetJob() *PipelineJob

func (*SubmitJobResponse) ProtoMessage

func (*SubmitJobResponse) ProtoMessage()

func (*SubmitJobResponse) ProtoReflect

func (x *SubmitJobResponse) ProtoReflect() protoreflect.Message

func (*SubmitJobResponse) Reset

func (x *SubmitJobResponse) Reset()

func (*SubmitJobResponse) String

func (x *SubmitJobResponse) String() string

func (*SubmitJobResponse) Validate

func (m *SubmitJobResponse) Validate() error

Validate checks the field values on SubmitJobResponse with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.

func (*SubmitJobResponse) ValidateAll

func (m *SubmitJobResponse) ValidateAll() error

ValidateAll checks the field values on SubmitJobResponse with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in SubmitJobResponseMultiError, or nil if none found.

type SubmitJobResponseMultiError

type SubmitJobResponseMultiError []error

SubmitJobResponseMultiError is an error wrapping multiple validation errors returned by SubmitJobResponse.ValidateAll() if the designated constraints aren't met.

func (SubmitJobResponseMultiError) AllErrors

func (m SubmitJobResponseMultiError) AllErrors() []error

AllErrors returns a list of validation violation errors.

func (SubmitJobResponseMultiError) Error

Error returns a concatenation of all the error messages it wraps.

type SubmitJobResponseValidationError

type SubmitJobResponseValidationError struct {
	// contains filtered or unexported fields
}

SubmitJobResponseValidationError is the validation error returned by SubmitJobResponse.Validate if the designated constraints aren't met.

func (SubmitJobResponseValidationError) Cause

Cause function returns cause value.

func (SubmitJobResponseValidationError) Error

Error satisfies the builtin error interface

func (SubmitJobResponseValidationError) ErrorName

ErrorName returns error name.

func (SubmitJobResponseValidationError) Field

Field function returns field value.

func (SubmitJobResponseValidationError) Key

Key function returns key value.

func (SubmitJobResponseValidationError) Reason

Reason function returns reason value.

Directories

Path Synopsis

Jump to