Documentation
¶
Index ¶
- Variables
- type ActionJobRequest
- func (*ActionJobRequest) Descriptor() ([]byte, []int)deprecated
- func (x *ActionJobRequest) GetAction() PipelineActionType
- func (x *ActionJobRequest) GetJobId() int64
- func (*ActionJobRequest) ProtoMessage()
- func (x *ActionJobRequest) ProtoReflect() protoreflect.Message
- func (x *ActionJobRequest) Reset()
- func (x *ActionJobRequest) String() string
- func (m *ActionJobRequest) Validate() error
- func (m *ActionJobRequest) ValidateAll() error
- type ActionJobRequestMultiError
- type ActionJobRequestValidationError
- func (e ActionJobRequestValidationError) Cause() error
- func (e ActionJobRequestValidationError) Error() string
- func (e ActionJobRequestValidationError) ErrorName() string
- func (e ActionJobRequestValidationError) Field() string
- func (e ActionJobRequestValidationError) Key() bool
- func (e ActionJobRequestValidationError) Reason() string
- type ActionJobResponse
- func (*ActionJobResponse) Descriptor() ([]byte, []int)deprecated
- func (x *ActionJobResponse) GetJob() *PipelineJob
- func (x *ActionJobResponse) GetNewJob() *PipelineJob
- func (*ActionJobResponse) ProtoMessage()
- func (x *ActionJobResponse) ProtoReflect() protoreflect.Message
- func (x *ActionJobResponse) Reset()
- func (x *ActionJobResponse) String() string
- func (m *ActionJobResponse) Validate() error
- func (m *ActionJobResponse) ValidateAll() error
- type ActionJobResponseMultiError
- type ActionJobResponseValidationError
- func (e ActionJobResponseValidationError) Cause() error
- func (e ActionJobResponseValidationError) Error() string
- func (e ActionJobResponseValidationError) ErrorName() string
- func (e ActionJobResponseValidationError) Field() string
- func (e ActionJobResponseValidationError) Key() bool
- func (e ActionJobResponseValidationError) Reason() string
- type ListJobStagesRequest
- func (*ListJobStagesRequest) Descriptor() ([]byte, []int)deprecated
- func (x *ListJobStagesRequest) GetJobId() int64
- func (*ListJobStagesRequest) ProtoMessage()
- func (x *ListJobStagesRequest) ProtoReflect() protoreflect.Message
- func (x *ListJobStagesRequest) Reset()
- func (x *ListJobStagesRequest) String() string
- func (m *ListJobStagesRequest) Validate() error
- func (m *ListJobStagesRequest) ValidateAll() error
- type ListJobStagesRequestMultiError
- type ListJobStagesRequestValidationError
- func (e ListJobStagesRequestValidationError) Cause() error
- func (e ListJobStagesRequestValidationError) Error() string
- func (e ListJobStagesRequestValidationError) ErrorName() string
- func (e ListJobStagesRequestValidationError) Field() string
- func (e ListJobStagesRequestValidationError) Key() bool
- func (e ListJobStagesRequestValidationError) Reason() string
- type ListJobStagesResponse
- func (*ListJobStagesResponse) Descriptor() ([]byte, []int)deprecated
- func (x *ListJobStagesResponse) GetStages() []*PipelineStage
- func (*ListJobStagesResponse) ProtoMessage()
- func (x *ListJobStagesResponse) ProtoReflect() protoreflect.Message
- func (x *ListJobStagesResponse) Reset()
- func (x *ListJobStagesResponse) String() string
- func (m *ListJobStagesResponse) Validate() error
- func (m *ListJobStagesResponse) ValidateAll() error
- type ListJobStagesResponseMultiError
- type ListJobStagesResponseValidationError
- func (e ListJobStagesResponseValidationError) Cause() error
- func (e ListJobStagesResponseValidationError) Error() string
- func (e ListJobStagesResponseValidationError) ErrorName() string
- func (e ListJobStagesResponseValidationError) Field() string
- func (e ListJobStagesResponseValidationError) Key() bool
- func (e ListJobStagesResponseValidationError) Reason() string
- type ListJobsRequest
- func (*ListJobsRequest) Descriptor() ([]byte, []int)deprecated
- func (x *ListJobsRequest) GetLemmaId() int64
- func (x *ListJobsRequest) GetPagination() *v1.PaginationRequest
- func (x *ListJobsRequest) GetStatus() PipelineStatus
- func (*ListJobsRequest) ProtoMessage()
- func (x *ListJobsRequest) ProtoReflect() protoreflect.Message
- func (x *ListJobsRequest) Reset()
- func (x *ListJobsRequest) String() string
- func (m *ListJobsRequest) Validate() error
- func (m *ListJobsRequest) ValidateAll() error
- type ListJobsRequestMultiError
- type ListJobsRequestValidationError
- func (e ListJobsRequestValidationError) Cause() error
- func (e ListJobsRequestValidationError) Error() string
- func (e ListJobsRequestValidationError) ErrorName() string
- func (e ListJobsRequestValidationError) Field() string
- func (e ListJobsRequestValidationError) Key() bool
- func (e ListJobsRequestValidationError) Reason() string
- type ListJobsResponse
- func (*ListJobsResponse) Descriptor() ([]byte, []int)deprecated
- func (x *ListJobsResponse) GetJobs() []*PipelineJob
- func (x *ListJobsResponse) GetPagination() *v1.PaginationResponse
- func (*ListJobsResponse) ProtoMessage()
- func (x *ListJobsResponse) ProtoReflect() protoreflect.Message
- func (x *ListJobsResponse) Reset()
- func (x *ListJobsResponse) String() string
- func (m *ListJobsResponse) Validate() error
- func (m *ListJobsResponse) ValidateAll() error
- type ListJobsResponseMultiError
- type ListJobsResponseValidationError
- func (e ListJobsResponseValidationError) Cause() error
- func (e ListJobsResponseValidationError) Error() string
- func (e ListJobsResponseValidationError) ErrorName() string
- func (e ListJobsResponseValidationError) Field() string
- func (e ListJobsResponseValidationError) Key() bool
- func (e ListJobsResponseValidationError) Reason() string
- type PipelineActionType
- func (PipelineActionType) Descriptor() protoreflect.EnumDescriptor
- func (x PipelineActionType) Enum() *PipelineActionType
- func (PipelineActionType) EnumDescriptor() ([]byte, []int)deprecated
- func (x PipelineActionType) Number() protoreflect.EnumNumber
- func (x PipelineActionType) String() string
- func (PipelineActionType) Type() protoreflect.EnumType
- type PipelineJob
- func (*PipelineJob) Descriptor() ([]byte, []int)deprecated
- func (x *PipelineJob) GetCompletedAt() *timestamppb.Timestamp
- func (x *PipelineJob) GetCreatedAt() *timestamppb.Timestamp
- func (x *PipelineJob) GetErrorMessage() string
- func (x *PipelineJob) GetId() int64
- func (x *PipelineJob) GetLanguage() string
- func (x *PipelineJob) GetName() string
- func (x *PipelineJob) GetStartedAt() *timestamppb.Timestamp
- func (x *PipelineJob) GetStatus() PipelineStatus
- func (x *PipelineJob) GetTerm() string
- func (x *PipelineJob) GetTier() int32
- func (x *PipelineJob) GetUpdatedAt() *timestamppb.Timestamp
- func (*PipelineJob) ProtoMessage()
- func (x *PipelineJob) ProtoReflect() protoreflect.Message
- func (x *PipelineJob) Reset()
- func (x *PipelineJob) String() string
- func (m *PipelineJob) Validate() error
- func (m *PipelineJob) ValidateAll() error
- type PipelineJobMultiError
- type PipelineJobValidationError
- func (e PipelineJobValidationError) Cause() error
- func (e PipelineJobValidationError) Error() string
- func (e PipelineJobValidationError) ErrorName() string
- func (e PipelineJobValidationError) Field() string
- func (e PipelineJobValidationError) Key() bool
- func (e PipelineJobValidationError) Reason() string
- type PipelinePhase
- func (PipelinePhase) Descriptor() protoreflect.EnumDescriptor
- func (x PipelinePhase) Enum() *PipelinePhase
- func (PipelinePhase) EnumDescriptor() ([]byte, []int)deprecated
- func (x PipelinePhase) Number() protoreflect.EnumNumber
- func (x PipelinePhase) String() string
- func (PipelinePhase) Type() protoreflect.EnumType
- type PipelineStage
- func (*PipelineStage) Descriptor() ([]byte, []int)deprecated
- func (x *PipelineStage) GetAttempts() int32
- func (x *PipelineStage) GetCompletedAt() *timestamppb.Timestamp
- func (x *PipelineStage) GetCreatedAt() *timestamppb.Timestamp
- func (x *PipelineStage) GetErrorMessage() string
- func (x *PipelineStage) GetId() int64
- func (x *PipelineStage) GetJobId() int64
- func (x *PipelineStage) GetLemmaId() int64
- func (x *PipelineStage) GetPhase() PipelinePhase
- func (x *PipelineStage) GetStartedAt() *timestamppb.Timestamp
- func (x *PipelineStage) GetStatus() PipelineStatus
- func (x *PipelineStage) GetUpdatedAt() *timestamppb.Timestamp
- func (*PipelineStage) ProtoMessage()
- func (x *PipelineStage) ProtoReflect() protoreflect.Message
- func (x *PipelineStage) Reset()
- func (x *PipelineStage) String() string
- func (m *PipelineStage) Validate() error
- func (m *PipelineStage) ValidateAll() error
- type PipelineStageMultiError
- type PipelineStageValidationError
- func (e PipelineStageValidationError) Cause() error
- func (e PipelineStageValidationError) Error() string
- func (e PipelineStageValidationError) ErrorName() string
- func (e PipelineStageValidationError) Field() string
- func (e PipelineStageValidationError) Key() bool
- func (e PipelineStageValidationError) Reason() string
- type PipelineStatus
- func (PipelineStatus) Descriptor() protoreflect.EnumDescriptor
- func (x PipelineStatus) Enum() *PipelineStatus
- func (PipelineStatus) EnumDescriptor() ([]byte, []int)deprecated
- func (x PipelineStatus) Number() protoreflect.EnumNumber
- func (x PipelineStatus) String() string
- func (PipelineStatus) Type() protoreflect.EnumType
- type SubmitJobRequest
- func (*SubmitJobRequest) Descriptor() ([]byte, []int)deprecated
- func (x *SubmitJobRequest) GetLanguage() string
- func (x *SubmitJobRequest) GetName() string
- func (x *SubmitJobRequest) GetTerm() string
- func (x *SubmitJobRequest) GetTier() int32
- func (*SubmitJobRequest) ProtoMessage()
- func (x *SubmitJobRequest) ProtoReflect() protoreflect.Message
- func (x *SubmitJobRequest) Reset()
- func (x *SubmitJobRequest) String() string
- func (m *SubmitJobRequest) Validate() error
- func (m *SubmitJobRequest) ValidateAll() error
- type SubmitJobRequestMultiError
- type SubmitJobRequestValidationError
- func (e SubmitJobRequestValidationError) Cause() error
- func (e SubmitJobRequestValidationError) Error() string
- func (e SubmitJobRequestValidationError) ErrorName() string
- func (e SubmitJobRequestValidationError) Field() string
- func (e SubmitJobRequestValidationError) Key() bool
- func (e SubmitJobRequestValidationError) Reason() string
- type SubmitJobResponse
- func (*SubmitJobResponse) Descriptor() ([]byte, []int)deprecated
- func (x *SubmitJobResponse) GetJob() *PipelineJob
- func (*SubmitJobResponse) ProtoMessage()
- func (x *SubmitJobResponse) ProtoReflect() protoreflect.Message
- func (x *SubmitJobResponse) Reset()
- func (x *SubmitJobResponse) String() string
- func (m *SubmitJobResponse) Validate() error
- func (m *SubmitJobResponse) ValidateAll() error
- type SubmitJobResponseMultiError
- type SubmitJobResponseValidationError
- func (e SubmitJobResponseValidationError) Cause() error
- func (e SubmitJobResponseValidationError) Error() string
- func (e SubmitJobResponseValidationError) ErrorName() string
- func (e SubmitJobResponseValidationError) Field() string
- func (e SubmitJobResponseValidationError) Key() bool
- func (e SubmitJobResponseValidationError) Reason() string
Constants ¶
This section is empty.
Variables ¶
var ( PipelineStatus_name = map[int32]string{ 0: "PIPELINE_STATUS_UNSPECIFIED", 1: "PIPELINE_STATUS_PENDING", 2: "PIPELINE_STATUS_RUNNING", 3: "PIPELINE_STATUS_PAUSED", 4: "PIPELINE_STATUS_COMPLETED", 5: "PIPELINE_STATUS_FAILED", 6: "PIPELINE_STATUS_CANCELLED", 7: "PIPELINE_STATUS_SKIPPED", } PipelineStatus_value = map[string]int32{ "PIPELINE_STATUS_UNSPECIFIED": 0, "PIPELINE_STATUS_PENDING": 1, "PIPELINE_STATUS_RUNNING": 2, "PIPELINE_STATUS_PAUSED": 3, "PIPELINE_STATUS_COMPLETED": 4, "PIPELINE_STATUS_FAILED": 5, "PIPELINE_STATUS_CANCELLED": 6, "PIPELINE_STATUS_SKIPPED": 7, } )
Enum value maps for PipelineStatus.
var ( PipelinePhase_name = map[int32]string{ 0: "PIPELINE_PHASE_UNSPECIFIED", 1: "PIPELINE_PHASE_COLLECTION", 2: "PIPELINE_PHASE_EVALUATION", 3: "PIPELINE_PHASE_INTEGRATION", 4: "PIPELINE_PHASE_SNAPSHOT", } PipelinePhase_value = map[string]int32{ "PIPELINE_PHASE_UNSPECIFIED": 0, "PIPELINE_PHASE_COLLECTION": 1, "PIPELINE_PHASE_EVALUATION": 2, "PIPELINE_PHASE_INTEGRATION": 3, "PIPELINE_PHASE_SNAPSHOT": 4, } )
Enum value maps for PipelinePhase.
var ( PipelineActionType_name = map[int32]string{ 0: "PIPELINE_ACTION_TYPE_UNSPECIFIED", 1: "PIPELINE_ACTION_TYPE_CANCEL", 2: "PIPELINE_ACTION_TYPE_RENEW", } PipelineActionType_value = map[string]int32{ "PIPELINE_ACTION_TYPE_UNSPECIFIED": 0, "PIPELINE_ACTION_TYPE_CANCEL": 1, "PIPELINE_ACTION_TYPE_RENEW": 2, } )
Enum value maps for PipelineActionType.
var File_pipeline_v1_pipeline_proto protoreflect.FileDescriptor
var File_pipeline_v1_pipeline_service_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type ActionJobRequest ¶
type ActionJobRequest struct {
JobId int64 `protobuf:"varint,1,opt,name=job_id,json=jobId,proto3" json:"job_id,omitempty"`
Action PipelineActionType `protobuf:"varint,2,opt,name=action,proto3,enum=pipeline.v1.PipelineActionType" json:"action,omitempty"`
// contains filtered or unexported fields
}
func (*ActionJobRequest) Descriptor
deprecated
func (*ActionJobRequest) Descriptor() ([]byte, []int)
Deprecated: Use ActionJobRequest.ProtoReflect.Descriptor instead.
func (*ActionJobRequest) GetAction ¶
func (x *ActionJobRequest) GetAction() PipelineActionType
func (*ActionJobRequest) GetJobId ¶
func (x *ActionJobRequest) GetJobId() int64
func (*ActionJobRequest) ProtoMessage ¶
func (*ActionJobRequest) ProtoMessage()
func (*ActionJobRequest) ProtoReflect ¶
func (x *ActionJobRequest) ProtoReflect() protoreflect.Message
func (*ActionJobRequest) Reset ¶
func (x *ActionJobRequest) Reset()
func (*ActionJobRequest) String ¶
func (x *ActionJobRequest) String() string
func (*ActionJobRequest) Validate ¶
func (m *ActionJobRequest) Validate() error
Validate checks the field values on ActionJobRequest with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.
func (*ActionJobRequest) ValidateAll ¶
func (m *ActionJobRequest) ValidateAll() error
ValidateAll checks the field values on ActionJobRequest with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in ActionJobRequestMultiError, or nil if none found.
type ActionJobRequestMultiError ¶
type ActionJobRequestMultiError []error
ActionJobRequestMultiError is an error wrapping multiple validation errors returned by ActionJobRequest.ValidateAll() if the designated constraints aren't met.
func (ActionJobRequestMultiError) AllErrors ¶
func (m ActionJobRequestMultiError) AllErrors() []error
AllErrors returns a list of validation violation errors.
func (ActionJobRequestMultiError) Error ¶
func (m ActionJobRequestMultiError) Error() string
Error returns a concatenation of all the error messages it wraps.
type ActionJobRequestValidationError ¶
type ActionJobRequestValidationError struct {
// contains filtered or unexported fields
}
ActionJobRequestValidationError is the validation error returned by ActionJobRequest.Validate if the designated constraints aren't met.
func (ActionJobRequestValidationError) Cause ¶
func (e ActionJobRequestValidationError) Cause() error
Cause function returns cause value.
func (ActionJobRequestValidationError) Error ¶
func (e ActionJobRequestValidationError) Error() string
Error satisfies the builtin error interface
func (ActionJobRequestValidationError) ErrorName ¶
func (e ActionJobRequestValidationError) ErrorName() string
ErrorName returns error name.
func (ActionJobRequestValidationError) Field ¶
func (e ActionJobRequestValidationError) Field() string
Field function returns field value.
func (ActionJobRequestValidationError) Key ¶
func (e ActionJobRequestValidationError) Key() bool
Key function returns key value.
func (ActionJobRequestValidationError) Reason ¶
func (e ActionJobRequestValidationError) Reason() string
Reason function returns reason value.
type ActionJobResponse ¶
type ActionJobResponse struct {
// For cancel action, this is the updated job.
Job *PipelineJob `protobuf:"bytes,1,opt,name=job,proto3" json:"job,omitempty"`
// For renew action, this is the newly created job.
NewJob *PipelineJob `protobuf:"bytes,2,opt,name=new_job,json=newJob,proto3" json:"new_job,omitempty"`
// contains filtered or unexported fields
}
func (*ActionJobResponse) Descriptor
deprecated
func (*ActionJobResponse) Descriptor() ([]byte, []int)
Deprecated: Use ActionJobResponse.ProtoReflect.Descriptor instead.
func (*ActionJobResponse) GetJob ¶
func (x *ActionJobResponse) GetJob() *PipelineJob
func (*ActionJobResponse) GetNewJob ¶
func (x *ActionJobResponse) GetNewJob() *PipelineJob
func (*ActionJobResponse) ProtoMessage ¶
func (*ActionJobResponse) ProtoMessage()
func (*ActionJobResponse) ProtoReflect ¶
func (x *ActionJobResponse) ProtoReflect() protoreflect.Message
func (*ActionJobResponse) Reset ¶
func (x *ActionJobResponse) Reset()
func (*ActionJobResponse) String ¶
func (x *ActionJobResponse) String() string
func (*ActionJobResponse) Validate ¶
func (m *ActionJobResponse) Validate() error
Validate checks the field values on ActionJobResponse with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.
func (*ActionJobResponse) ValidateAll ¶
func (m *ActionJobResponse) ValidateAll() error
ValidateAll checks the field values on ActionJobResponse with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in ActionJobResponseMultiError, or nil if none found.
type ActionJobResponseMultiError ¶
type ActionJobResponseMultiError []error
ActionJobResponseMultiError is an error wrapping multiple validation errors returned by ActionJobResponse.ValidateAll() if the designated constraints aren't met.
func (ActionJobResponseMultiError) AllErrors ¶
func (m ActionJobResponseMultiError) AllErrors() []error
AllErrors returns a list of validation violation errors.
func (ActionJobResponseMultiError) Error ¶
func (m ActionJobResponseMultiError) Error() string
Error returns a concatenation of all the error messages it wraps.
type ActionJobResponseValidationError ¶
type ActionJobResponseValidationError struct {
// contains filtered or unexported fields
}
ActionJobResponseValidationError is the validation error returned by ActionJobResponse.Validate if the designated constraints aren't met.
func (ActionJobResponseValidationError) Cause ¶
func (e ActionJobResponseValidationError) Cause() error
Cause function returns cause value.
func (ActionJobResponseValidationError) Error ¶
func (e ActionJobResponseValidationError) Error() string
Error satisfies the builtin error interface
func (ActionJobResponseValidationError) ErrorName ¶
func (e ActionJobResponseValidationError) ErrorName() string
ErrorName returns error name.
func (ActionJobResponseValidationError) Field ¶
func (e ActionJobResponseValidationError) Field() string
Field function returns field value.
func (ActionJobResponseValidationError) Key ¶
func (e ActionJobResponseValidationError) Key() bool
Key function returns key value.
func (ActionJobResponseValidationError) Reason ¶
func (e ActionJobResponseValidationError) Reason() string
Reason function returns reason value.
type ListJobStagesRequest ¶
type ListJobStagesRequest struct {
JobId int64 `protobuf:"varint,1,opt,name=job_id,json=jobId,proto3" json:"job_id,omitempty"`
// contains filtered or unexported fields
}
func (*ListJobStagesRequest) Descriptor
deprecated
func (*ListJobStagesRequest) Descriptor() ([]byte, []int)
Deprecated: Use ListJobStagesRequest.ProtoReflect.Descriptor instead.
func (*ListJobStagesRequest) GetJobId ¶
func (x *ListJobStagesRequest) GetJobId() int64
func (*ListJobStagesRequest) ProtoMessage ¶
func (*ListJobStagesRequest) ProtoMessage()
func (*ListJobStagesRequest) ProtoReflect ¶
func (x *ListJobStagesRequest) ProtoReflect() protoreflect.Message
func (*ListJobStagesRequest) Reset ¶
func (x *ListJobStagesRequest) Reset()
func (*ListJobStagesRequest) String ¶
func (x *ListJobStagesRequest) String() string
func (*ListJobStagesRequest) Validate ¶
func (m *ListJobStagesRequest) Validate() error
Validate checks the field values on ListJobStagesRequest with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.
func (*ListJobStagesRequest) ValidateAll ¶
func (m *ListJobStagesRequest) ValidateAll() error
ValidateAll checks the field values on ListJobStagesRequest with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in ListJobStagesRequestMultiError, or nil if none found.
type ListJobStagesRequestMultiError ¶
type ListJobStagesRequestMultiError []error
ListJobStagesRequestMultiError is an error wrapping multiple validation errors returned by ListJobStagesRequest.ValidateAll() if the designated constraints aren't met.
func (ListJobStagesRequestMultiError) AllErrors ¶
func (m ListJobStagesRequestMultiError) AllErrors() []error
AllErrors returns a list of validation violation errors.
func (ListJobStagesRequestMultiError) Error ¶
func (m ListJobStagesRequestMultiError) Error() string
Error returns a concatenation of all the error messages it wraps.
type ListJobStagesRequestValidationError ¶
type ListJobStagesRequestValidationError struct {
// contains filtered or unexported fields
}
ListJobStagesRequestValidationError is the validation error returned by ListJobStagesRequest.Validate if the designated constraints aren't met.
func (ListJobStagesRequestValidationError) Cause ¶
func (e ListJobStagesRequestValidationError) Cause() error
Cause function returns cause value.
func (ListJobStagesRequestValidationError) Error ¶
func (e ListJobStagesRequestValidationError) Error() string
Error satisfies the builtin error interface
func (ListJobStagesRequestValidationError) ErrorName ¶
func (e ListJobStagesRequestValidationError) ErrorName() string
ErrorName returns error name.
func (ListJobStagesRequestValidationError) Field ¶
func (e ListJobStagesRequestValidationError) Field() string
Field function returns field value.
func (ListJobStagesRequestValidationError) Key ¶
func (e ListJobStagesRequestValidationError) Key() bool
Key function returns key value.
func (ListJobStagesRequestValidationError) Reason ¶
func (e ListJobStagesRequestValidationError) Reason() string
Reason function returns reason value.
type ListJobStagesResponse ¶
type ListJobStagesResponse struct {
Stages []*PipelineStage `protobuf:"bytes,1,rep,name=stages,proto3" json:"stages,omitempty"`
// contains filtered or unexported fields
}
func (*ListJobStagesResponse) Descriptor
deprecated
func (*ListJobStagesResponse) Descriptor() ([]byte, []int)
Deprecated: Use ListJobStagesResponse.ProtoReflect.Descriptor instead.
func (*ListJobStagesResponse) GetStages ¶
func (x *ListJobStagesResponse) GetStages() []*PipelineStage
func (*ListJobStagesResponse) ProtoMessage ¶
func (*ListJobStagesResponse) ProtoMessage()
func (*ListJobStagesResponse) ProtoReflect ¶
func (x *ListJobStagesResponse) ProtoReflect() protoreflect.Message
func (*ListJobStagesResponse) Reset ¶
func (x *ListJobStagesResponse) Reset()
func (*ListJobStagesResponse) String ¶
func (x *ListJobStagesResponse) String() string
func (*ListJobStagesResponse) Validate ¶
func (m *ListJobStagesResponse) Validate() error
Validate checks the field values on ListJobStagesResponse with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.
func (*ListJobStagesResponse) ValidateAll ¶
func (m *ListJobStagesResponse) ValidateAll() error
ValidateAll checks the field values on ListJobStagesResponse with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in ListJobStagesResponseMultiError, or nil if none found.
type ListJobStagesResponseMultiError ¶
type ListJobStagesResponseMultiError []error
ListJobStagesResponseMultiError is an error wrapping multiple validation errors returned by ListJobStagesResponse.ValidateAll() if the designated constraints aren't met.
func (ListJobStagesResponseMultiError) AllErrors ¶
func (m ListJobStagesResponseMultiError) AllErrors() []error
AllErrors returns a list of validation violation errors.
func (ListJobStagesResponseMultiError) Error ¶
func (m ListJobStagesResponseMultiError) Error() string
Error returns a concatenation of all the error messages it wraps.
type ListJobStagesResponseValidationError ¶
type ListJobStagesResponseValidationError struct {
// contains filtered or unexported fields
}
ListJobStagesResponseValidationError is the validation error returned by ListJobStagesResponse.Validate if the designated constraints aren't met.
func (ListJobStagesResponseValidationError) Cause ¶
func (e ListJobStagesResponseValidationError) Cause() error
Cause function returns cause value.
func (ListJobStagesResponseValidationError) Error ¶
func (e ListJobStagesResponseValidationError) Error() string
Error satisfies the builtin error interface
func (ListJobStagesResponseValidationError) ErrorName ¶
func (e ListJobStagesResponseValidationError) ErrorName() string
ErrorName returns error name.
func (ListJobStagesResponseValidationError) Field ¶
func (e ListJobStagesResponseValidationError) Field() string
Field function returns field value.
func (ListJobStagesResponseValidationError) Key ¶
func (e ListJobStagesResponseValidationError) Key() bool
Key function returns key value.
func (ListJobStagesResponseValidationError) Reason ¶
func (e ListJobStagesResponseValidationError) Reason() string
Reason function returns reason value.
type ListJobsRequest ¶
type ListJobsRequest struct {
Pagination *v1.PaginationRequest `protobuf:"bytes,1,opt,name=pagination,proto3" json:"pagination,omitempty"`
// Optional filter. UNSPECIFIED means no status filter.
Status PipelineStatus `protobuf:"varint,2,opt,name=status,proto3,enum=pipeline.v1.PipelineStatus" json:"status,omitempty"`
// Optional filter by lemma ID.
LemmaId int64 `protobuf:"varint,3,opt,name=lemma_id,json=lemmaId,proto3" json:"lemma_id,omitempty"`
// contains filtered or unexported fields
}
func (*ListJobsRequest) Descriptor
deprecated
func (*ListJobsRequest) Descriptor() ([]byte, []int)
Deprecated: Use ListJobsRequest.ProtoReflect.Descriptor instead.
func (*ListJobsRequest) GetLemmaId ¶
func (x *ListJobsRequest) GetLemmaId() int64
func (*ListJobsRequest) GetPagination ¶
func (x *ListJobsRequest) GetPagination() *v1.PaginationRequest
func (*ListJobsRequest) GetStatus ¶
func (x *ListJobsRequest) GetStatus() PipelineStatus
func (*ListJobsRequest) ProtoMessage ¶
func (*ListJobsRequest) ProtoMessage()
func (*ListJobsRequest) ProtoReflect ¶
func (x *ListJobsRequest) ProtoReflect() protoreflect.Message
func (*ListJobsRequest) Reset ¶
func (x *ListJobsRequest) Reset()
func (*ListJobsRequest) String ¶
func (x *ListJobsRequest) String() string
func (*ListJobsRequest) Validate ¶
func (m *ListJobsRequest) Validate() error
Validate checks the field values on ListJobsRequest with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.
func (*ListJobsRequest) ValidateAll ¶
func (m *ListJobsRequest) ValidateAll() error
ValidateAll checks the field values on ListJobsRequest with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in ListJobsRequestMultiError, or nil if none found.
type ListJobsRequestMultiError ¶
type ListJobsRequestMultiError []error
ListJobsRequestMultiError is an error wrapping multiple validation errors returned by ListJobsRequest.ValidateAll() if the designated constraints aren't met.
func (ListJobsRequestMultiError) AllErrors ¶
func (m ListJobsRequestMultiError) AllErrors() []error
AllErrors returns a list of validation violation errors.
func (ListJobsRequestMultiError) Error ¶
func (m ListJobsRequestMultiError) Error() string
Error returns a concatenation of all the error messages it wraps.
type ListJobsRequestValidationError ¶
type ListJobsRequestValidationError struct {
// contains filtered or unexported fields
}
ListJobsRequestValidationError is the validation error returned by ListJobsRequest.Validate if the designated constraints aren't met.
func (ListJobsRequestValidationError) Cause ¶
func (e ListJobsRequestValidationError) Cause() error
Cause function returns cause value.
func (ListJobsRequestValidationError) Error ¶
func (e ListJobsRequestValidationError) Error() string
Error satisfies the builtin error interface
func (ListJobsRequestValidationError) ErrorName ¶
func (e ListJobsRequestValidationError) ErrorName() string
ErrorName returns error name.
func (ListJobsRequestValidationError) Field ¶
func (e ListJobsRequestValidationError) Field() string
Field function returns field value.
func (ListJobsRequestValidationError) Key ¶
func (e ListJobsRequestValidationError) Key() bool
Key function returns key value.
func (ListJobsRequestValidationError) Reason ¶
func (e ListJobsRequestValidationError) Reason() string
Reason function returns reason value.
type ListJobsResponse ¶
type ListJobsResponse struct {
Jobs []*PipelineJob `protobuf:"bytes,1,rep,name=jobs,proto3" json:"jobs,omitempty"`
Pagination *v1.PaginationResponse `protobuf:"bytes,2,opt,name=pagination,proto3" json:"pagination,omitempty"`
// contains filtered or unexported fields
}
func (*ListJobsResponse) Descriptor
deprecated
func (*ListJobsResponse) Descriptor() ([]byte, []int)
Deprecated: Use ListJobsResponse.ProtoReflect.Descriptor instead.
func (*ListJobsResponse) GetJobs ¶
func (x *ListJobsResponse) GetJobs() []*PipelineJob
func (*ListJobsResponse) GetPagination ¶
func (x *ListJobsResponse) GetPagination() *v1.PaginationResponse
func (*ListJobsResponse) ProtoMessage ¶
func (*ListJobsResponse) ProtoMessage()
func (*ListJobsResponse) ProtoReflect ¶
func (x *ListJobsResponse) ProtoReflect() protoreflect.Message
func (*ListJobsResponse) Reset ¶
func (x *ListJobsResponse) Reset()
func (*ListJobsResponse) String ¶
func (x *ListJobsResponse) String() string
func (*ListJobsResponse) Validate ¶
func (m *ListJobsResponse) Validate() error
Validate checks the field values on ListJobsResponse with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.
func (*ListJobsResponse) ValidateAll ¶
func (m *ListJobsResponse) ValidateAll() error
ValidateAll checks the field values on ListJobsResponse with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in ListJobsResponseMultiError, or nil if none found.
type ListJobsResponseMultiError ¶
type ListJobsResponseMultiError []error
ListJobsResponseMultiError is an error wrapping multiple validation errors returned by ListJobsResponse.ValidateAll() if the designated constraints aren't met.
func (ListJobsResponseMultiError) AllErrors ¶
func (m ListJobsResponseMultiError) AllErrors() []error
AllErrors returns a list of validation violation errors.
func (ListJobsResponseMultiError) Error ¶
func (m ListJobsResponseMultiError) Error() string
Error returns a concatenation of all the error messages it wraps.
type ListJobsResponseValidationError ¶
type ListJobsResponseValidationError struct {
// contains filtered or unexported fields
}
ListJobsResponseValidationError is the validation error returned by ListJobsResponse.Validate if the designated constraints aren't met.
func (ListJobsResponseValidationError) Cause ¶
func (e ListJobsResponseValidationError) Cause() error
Cause function returns cause value.
func (ListJobsResponseValidationError) Error ¶
func (e ListJobsResponseValidationError) Error() string
Error satisfies the builtin error interface
func (ListJobsResponseValidationError) ErrorName ¶
func (e ListJobsResponseValidationError) ErrorName() string
ErrorName returns error name.
func (ListJobsResponseValidationError) Field ¶
func (e ListJobsResponseValidationError) Field() string
Field function returns field value.
func (ListJobsResponseValidationError) Key ¶
func (e ListJobsResponseValidationError) Key() bool
Key function returns key value.
func (ListJobsResponseValidationError) Reason ¶
func (e ListJobsResponseValidationError) Reason() string
Reason function returns reason value.
type PipelineActionType ¶
type PipelineActionType int32
const ( PipelineActionType_PIPELINE_ACTION_TYPE_UNSPECIFIED PipelineActionType = 0 PipelineActionType_PIPELINE_ACTION_TYPE_CANCEL PipelineActionType = 1 // Renew creates a new pipeline run/job; it does not mutate stage execution of old job. PipelineActionType_PIPELINE_ACTION_TYPE_RENEW PipelineActionType = 2 )
func (PipelineActionType) Descriptor ¶
func (PipelineActionType) Descriptor() protoreflect.EnumDescriptor
func (PipelineActionType) Enum ¶
func (x PipelineActionType) Enum() *PipelineActionType
func (PipelineActionType) EnumDescriptor
deprecated
func (PipelineActionType) EnumDescriptor() ([]byte, []int)
Deprecated: Use PipelineActionType.Descriptor instead.
func (PipelineActionType) Number ¶
func (x PipelineActionType) Number() protoreflect.EnumNumber
func (PipelineActionType) String ¶
func (x PipelineActionType) String() string
func (PipelineActionType) Type ¶
func (PipelineActionType) Type() protoreflect.EnumType
type PipelineJob ¶
type PipelineJob struct {
Id int64 `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
Status PipelineStatus `protobuf:"varint,2,opt,name=status,proto3,enum=pipeline.v1.PipelineStatus" json:"status,omitempty"`
Name string `protobuf:"bytes,3,opt,name=name,proto3" json:"name,omitempty"`
Language string `protobuf:"bytes,4,opt,name=language,proto3" json:"language,omitempty"`
Tier int32 `protobuf:"varint,5,opt,name=tier,proto3" json:"tier,omitempty"`
Term string `protobuf:"bytes,6,opt,name=term,proto3" json:"term,omitempty"`
ErrorMessage string `protobuf:"bytes,7,opt,name=error_message,json=errorMessage,proto3" json:"error_message,omitempty"`
StartedAt *timestamppb.Timestamp `protobuf:"bytes,8,opt,name=started_at,json=startedAt,proto3" json:"started_at,omitempty"`
CompletedAt *timestamppb.Timestamp `protobuf:"bytes,9,opt,name=completed_at,json=completedAt,proto3" json:"completed_at,omitempty"`
CreatedAt *timestamppb.Timestamp `protobuf:"bytes,10,opt,name=created_at,json=createdAt,proto3" json:"created_at,omitempty"`
UpdatedAt *timestamppb.Timestamp `protobuf:"bytes,11,opt,name=updated_at,json=updatedAt,proto3" json:"updated_at,omitempty"`
// contains filtered or unexported fields
}
func (*PipelineJob) Descriptor
deprecated
func (*PipelineJob) Descriptor() ([]byte, []int)
Deprecated: Use PipelineJob.ProtoReflect.Descriptor instead.
func (*PipelineJob) GetCompletedAt ¶
func (x *PipelineJob) GetCompletedAt() *timestamppb.Timestamp
func (*PipelineJob) GetCreatedAt ¶
func (x *PipelineJob) GetCreatedAt() *timestamppb.Timestamp
func (*PipelineJob) GetErrorMessage ¶
func (x *PipelineJob) GetErrorMessage() string
func (*PipelineJob) GetId ¶
func (x *PipelineJob) GetId() int64
func (*PipelineJob) GetLanguage ¶
func (x *PipelineJob) GetLanguage() string
func (*PipelineJob) GetName ¶
func (x *PipelineJob) GetName() string
func (*PipelineJob) GetStartedAt ¶
func (x *PipelineJob) GetStartedAt() *timestamppb.Timestamp
func (*PipelineJob) GetStatus ¶
func (x *PipelineJob) GetStatus() PipelineStatus
func (*PipelineJob) GetTerm ¶
func (x *PipelineJob) GetTerm() string
func (*PipelineJob) GetTier ¶
func (x *PipelineJob) GetTier() int32
func (*PipelineJob) GetUpdatedAt ¶
func (x *PipelineJob) GetUpdatedAt() *timestamppb.Timestamp
func (*PipelineJob) ProtoMessage ¶
func (*PipelineJob) ProtoMessage()
func (*PipelineJob) ProtoReflect ¶
func (x *PipelineJob) ProtoReflect() protoreflect.Message
func (*PipelineJob) Reset ¶
func (x *PipelineJob) Reset()
func (*PipelineJob) String ¶
func (x *PipelineJob) String() string
func (*PipelineJob) Validate ¶
func (m *PipelineJob) Validate() error
Validate checks the field values on PipelineJob with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.
func (*PipelineJob) ValidateAll ¶
func (m *PipelineJob) ValidateAll() error
ValidateAll checks the field values on PipelineJob with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in PipelineJobMultiError, or nil if none found.
type PipelineJobMultiError ¶
type PipelineJobMultiError []error
PipelineJobMultiError is an error wrapping multiple validation errors returned by PipelineJob.ValidateAll() if the designated constraints aren't met.
func (PipelineJobMultiError) AllErrors ¶
func (m PipelineJobMultiError) AllErrors() []error
AllErrors returns a list of validation violation errors.
func (PipelineJobMultiError) Error ¶
func (m PipelineJobMultiError) Error() string
Error returns a concatenation of all the error messages it wraps.
type PipelineJobValidationError ¶
type PipelineJobValidationError struct {
// contains filtered or unexported fields
}
PipelineJobValidationError is the validation error returned by PipelineJob.Validate if the designated constraints aren't met.
func (PipelineJobValidationError) Cause ¶
func (e PipelineJobValidationError) Cause() error
Cause function returns cause value.
func (PipelineJobValidationError) Error ¶
func (e PipelineJobValidationError) Error() string
Error satisfies the builtin error interface
func (PipelineJobValidationError) ErrorName ¶
func (e PipelineJobValidationError) ErrorName() string
ErrorName returns error name.
func (PipelineJobValidationError) Field ¶
func (e PipelineJobValidationError) Field() string
Field function returns field value.
func (PipelineJobValidationError) Key ¶
func (e PipelineJobValidationError) Key() bool
Key function returns key value.
func (PipelineJobValidationError) Reason ¶
func (e PipelineJobValidationError) Reason() string
Reason function returns reason value.
type PipelinePhase ¶
type PipelinePhase int32
const ( PipelinePhase_PIPELINE_PHASE_UNSPECIFIED PipelinePhase = 0 PipelinePhase_PIPELINE_PHASE_COLLECTION PipelinePhase = 1 PipelinePhase_PIPELINE_PHASE_EVALUATION PipelinePhase = 2 PipelinePhase_PIPELINE_PHASE_INTEGRATION PipelinePhase = 3 PipelinePhase_PIPELINE_PHASE_SNAPSHOT PipelinePhase = 4 )
func (PipelinePhase) Descriptor ¶
func (PipelinePhase) Descriptor() protoreflect.EnumDescriptor
func (PipelinePhase) Enum ¶
func (x PipelinePhase) Enum() *PipelinePhase
func (PipelinePhase) EnumDescriptor
deprecated
func (PipelinePhase) EnumDescriptor() ([]byte, []int)
Deprecated: Use PipelinePhase.Descriptor instead.
func (PipelinePhase) Number ¶
func (x PipelinePhase) Number() protoreflect.EnumNumber
func (PipelinePhase) String ¶
func (x PipelinePhase) String() string
func (PipelinePhase) Type ¶
func (PipelinePhase) Type() protoreflect.EnumType
type PipelineStage ¶
type PipelineStage struct {
Id int64 `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
JobId int64 `protobuf:"varint,2,opt,name=job_id,json=jobId,proto3" json:"job_id,omitempty"`
LemmaId int64 `protobuf:"varint,3,opt,name=lemma_id,json=lemmaId,proto3" json:"lemma_id,omitempty"`
Phase PipelinePhase `protobuf:"varint,4,opt,name=phase,proto3,enum=pipeline.v1.PipelinePhase" json:"phase,omitempty"`
Status PipelineStatus `protobuf:"varint,5,opt,name=status,proto3,enum=pipeline.v1.PipelineStatus" json:"status,omitempty"`
Attempts int32 `protobuf:"varint,6,opt,name=attempts,proto3" json:"attempts,omitempty"`
ErrorMessage string `protobuf:"bytes,7,opt,name=error_message,json=errorMessage,proto3" json:"error_message,omitempty"`
StartedAt *timestamppb.Timestamp `protobuf:"bytes,8,opt,name=started_at,json=startedAt,proto3" json:"started_at,omitempty"`
CompletedAt *timestamppb.Timestamp `protobuf:"bytes,9,opt,name=completed_at,json=completedAt,proto3" json:"completed_at,omitempty"`
CreatedAt *timestamppb.Timestamp `protobuf:"bytes,10,opt,name=created_at,json=createdAt,proto3" json:"created_at,omitempty"`
UpdatedAt *timestamppb.Timestamp `protobuf:"bytes,11,opt,name=updated_at,json=updatedAt,proto3" json:"updated_at,omitempty"`
// contains filtered or unexported fields
}
func (*PipelineStage) Descriptor
deprecated
func (*PipelineStage) Descriptor() ([]byte, []int)
Deprecated: Use PipelineStage.ProtoReflect.Descriptor instead.
func (*PipelineStage) GetAttempts ¶
func (x *PipelineStage) GetAttempts() int32
func (*PipelineStage) GetCompletedAt ¶
func (x *PipelineStage) GetCompletedAt() *timestamppb.Timestamp
func (*PipelineStage) GetCreatedAt ¶
func (x *PipelineStage) GetCreatedAt() *timestamppb.Timestamp
func (*PipelineStage) GetErrorMessage ¶
func (x *PipelineStage) GetErrorMessage() string
func (*PipelineStage) GetId ¶
func (x *PipelineStage) GetId() int64
func (*PipelineStage) GetJobId ¶
func (x *PipelineStage) GetJobId() int64
func (*PipelineStage) GetLemmaId ¶
func (x *PipelineStage) GetLemmaId() int64
func (*PipelineStage) GetPhase ¶
func (x *PipelineStage) GetPhase() PipelinePhase
func (*PipelineStage) GetStartedAt ¶
func (x *PipelineStage) GetStartedAt() *timestamppb.Timestamp
func (*PipelineStage) GetStatus ¶
func (x *PipelineStage) GetStatus() PipelineStatus
func (*PipelineStage) GetUpdatedAt ¶
func (x *PipelineStage) GetUpdatedAt() *timestamppb.Timestamp
func (*PipelineStage) ProtoMessage ¶
func (*PipelineStage) ProtoMessage()
func (*PipelineStage) ProtoReflect ¶
func (x *PipelineStage) ProtoReflect() protoreflect.Message
func (*PipelineStage) Reset ¶
func (x *PipelineStage) Reset()
func (*PipelineStage) String ¶
func (x *PipelineStage) String() string
func (*PipelineStage) Validate ¶
func (m *PipelineStage) Validate() error
Validate checks the field values on PipelineStage with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.
func (*PipelineStage) ValidateAll ¶
func (m *PipelineStage) ValidateAll() error
ValidateAll checks the field values on PipelineStage with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in PipelineStageMultiError, or nil if none found.
type PipelineStageMultiError ¶
type PipelineStageMultiError []error
PipelineStageMultiError is an error wrapping multiple validation errors returned by PipelineStage.ValidateAll() if the designated constraints aren't met.
func (PipelineStageMultiError) AllErrors ¶
func (m PipelineStageMultiError) AllErrors() []error
AllErrors returns a list of validation violation errors.
func (PipelineStageMultiError) Error ¶
func (m PipelineStageMultiError) Error() string
Error returns a concatenation of all the error messages it wraps.
type PipelineStageValidationError ¶
type PipelineStageValidationError struct {
// contains filtered or unexported fields
}
PipelineStageValidationError is the validation error returned by PipelineStage.Validate if the designated constraints aren't met.
func (PipelineStageValidationError) Cause ¶
func (e PipelineStageValidationError) Cause() error
Cause function returns cause value.
func (PipelineStageValidationError) Error ¶
func (e PipelineStageValidationError) Error() string
Error satisfies the builtin error interface
func (PipelineStageValidationError) ErrorName ¶
func (e PipelineStageValidationError) ErrorName() string
ErrorName returns error name.
func (PipelineStageValidationError) Field ¶
func (e PipelineStageValidationError) Field() string
Field function returns field value.
func (PipelineStageValidationError) Key ¶
func (e PipelineStageValidationError) Key() bool
Key function returns key value.
func (PipelineStageValidationError) Reason ¶
func (e PipelineStageValidationError) Reason() string
Reason function returns reason value.
type PipelineStatus ¶
type PipelineStatus int32
const ( PipelineStatus_PIPELINE_STATUS_UNSPECIFIED PipelineStatus = 0 PipelineStatus_PIPELINE_STATUS_PENDING PipelineStatus = 1 PipelineStatus_PIPELINE_STATUS_RUNNING PipelineStatus = 2 PipelineStatus_PIPELINE_STATUS_PAUSED PipelineStatus = 3 PipelineStatus_PIPELINE_STATUS_COMPLETED PipelineStatus = 4 PipelineStatus_PIPELINE_STATUS_FAILED PipelineStatus = 5 PipelineStatus_PIPELINE_STATUS_CANCELLED PipelineStatus = 6 PipelineStatus_PIPELINE_STATUS_SKIPPED PipelineStatus = 7 )
func (PipelineStatus) Descriptor ¶
func (PipelineStatus) Descriptor() protoreflect.EnumDescriptor
func (PipelineStatus) Enum ¶
func (x PipelineStatus) Enum() *PipelineStatus
func (PipelineStatus) EnumDescriptor
deprecated
func (PipelineStatus) EnumDescriptor() ([]byte, []int)
Deprecated: Use PipelineStatus.Descriptor instead.
func (PipelineStatus) Number ¶
func (x PipelineStatus) Number() protoreflect.EnumNumber
func (PipelineStatus) String ¶
func (x PipelineStatus) String() string
func (PipelineStatus) Type ¶
func (PipelineStatus) Type() protoreflect.EnumType
type SubmitJobRequest ¶
type SubmitJobRequest struct {
Term string `protobuf:"bytes,1,opt,name=term,proto3" json:"term,omitempty"`
Language string `protobuf:"bytes,2,opt,name=language,proto3" json:"language,omitempty"`
Tier int32 `protobuf:"varint,3,opt,name=tier,proto3" json:"tier,omitempty"`
Name string `protobuf:"bytes,4,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
func (*SubmitJobRequest) Descriptor
deprecated
func (*SubmitJobRequest) Descriptor() ([]byte, []int)
Deprecated: Use SubmitJobRequest.ProtoReflect.Descriptor instead.
func (*SubmitJobRequest) GetLanguage ¶
func (x *SubmitJobRequest) GetLanguage() string
func (*SubmitJobRequest) GetName ¶
func (x *SubmitJobRequest) GetName() string
func (*SubmitJobRequest) GetTerm ¶
func (x *SubmitJobRequest) GetTerm() string
func (*SubmitJobRequest) GetTier ¶
func (x *SubmitJobRequest) GetTier() int32
func (*SubmitJobRequest) ProtoMessage ¶
func (*SubmitJobRequest) ProtoMessage()
func (*SubmitJobRequest) ProtoReflect ¶
func (x *SubmitJobRequest) ProtoReflect() protoreflect.Message
func (*SubmitJobRequest) Reset ¶
func (x *SubmitJobRequest) Reset()
func (*SubmitJobRequest) String ¶
func (x *SubmitJobRequest) String() string
func (*SubmitJobRequest) Validate ¶
func (m *SubmitJobRequest) Validate() error
Validate checks the field values on SubmitJobRequest with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.
func (*SubmitJobRequest) ValidateAll ¶
func (m *SubmitJobRequest) ValidateAll() error
ValidateAll checks the field values on SubmitJobRequest with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in SubmitJobRequestMultiError, or nil if none found.
type SubmitJobRequestMultiError ¶
type SubmitJobRequestMultiError []error
SubmitJobRequestMultiError is an error wrapping multiple validation errors returned by SubmitJobRequest.ValidateAll() if the designated constraints aren't met.
func (SubmitJobRequestMultiError) AllErrors ¶
func (m SubmitJobRequestMultiError) AllErrors() []error
AllErrors returns a list of validation violation errors.
func (SubmitJobRequestMultiError) Error ¶
func (m SubmitJobRequestMultiError) Error() string
Error returns a concatenation of all the error messages it wraps.
type SubmitJobRequestValidationError ¶
type SubmitJobRequestValidationError struct {
// contains filtered or unexported fields
}
SubmitJobRequestValidationError is the validation error returned by SubmitJobRequest.Validate if the designated constraints aren't met.
func (SubmitJobRequestValidationError) Cause ¶
func (e SubmitJobRequestValidationError) Cause() error
Cause function returns cause value.
func (SubmitJobRequestValidationError) Error ¶
func (e SubmitJobRequestValidationError) Error() string
Error satisfies the builtin error interface
func (SubmitJobRequestValidationError) ErrorName ¶
func (e SubmitJobRequestValidationError) ErrorName() string
ErrorName returns error name.
func (SubmitJobRequestValidationError) Field ¶
func (e SubmitJobRequestValidationError) Field() string
Field function returns field value.
func (SubmitJobRequestValidationError) Key ¶
func (e SubmitJobRequestValidationError) Key() bool
Key function returns key value.
func (SubmitJobRequestValidationError) Reason ¶
func (e SubmitJobRequestValidationError) Reason() string
Reason function returns reason value.
type SubmitJobResponse ¶
type SubmitJobResponse struct {
Job *PipelineJob `protobuf:"bytes,1,opt,name=job,proto3" json:"job,omitempty"`
// contains filtered or unexported fields
}
func (*SubmitJobResponse) Descriptor
deprecated
func (*SubmitJobResponse) Descriptor() ([]byte, []int)
Deprecated: Use SubmitJobResponse.ProtoReflect.Descriptor instead.
func (*SubmitJobResponse) GetJob ¶
func (x *SubmitJobResponse) GetJob() *PipelineJob
func (*SubmitJobResponse) ProtoMessage ¶
func (*SubmitJobResponse) ProtoMessage()
func (*SubmitJobResponse) ProtoReflect ¶
func (x *SubmitJobResponse) ProtoReflect() protoreflect.Message
func (*SubmitJobResponse) Reset ¶
func (x *SubmitJobResponse) Reset()
func (*SubmitJobResponse) String ¶
func (x *SubmitJobResponse) String() string
func (*SubmitJobResponse) Validate ¶
func (m *SubmitJobResponse) Validate() error
Validate checks the field values on SubmitJobResponse with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.
func (*SubmitJobResponse) ValidateAll ¶
func (m *SubmitJobResponse) ValidateAll() error
ValidateAll checks the field values on SubmitJobResponse with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in SubmitJobResponseMultiError, or nil if none found.
type SubmitJobResponseMultiError ¶
type SubmitJobResponseMultiError []error
SubmitJobResponseMultiError is an error wrapping multiple validation errors returned by SubmitJobResponse.ValidateAll() if the designated constraints aren't met.
func (SubmitJobResponseMultiError) AllErrors ¶
func (m SubmitJobResponseMultiError) AllErrors() []error
AllErrors returns a list of validation violation errors.
func (SubmitJobResponseMultiError) Error ¶
func (m SubmitJobResponseMultiError) Error() string
Error returns a concatenation of all the error messages it wraps.
type SubmitJobResponseValidationError ¶
type SubmitJobResponseValidationError struct {
// contains filtered or unexported fields
}
SubmitJobResponseValidationError is the validation error returned by SubmitJobResponse.Validate if the designated constraints aren't met.
func (SubmitJobResponseValidationError) Cause ¶
func (e SubmitJobResponseValidationError) Cause() error
Cause function returns cause value.
func (SubmitJobResponseValidationError) Error ¶
func (e SubmitJobResponseValidationError) Error() string
Error satisfies the builtin error interface
func (SubmitJobResponseValidationError) ErrorName ¶
func (e SubmitJobResponseValidationError) ErrorName() string
ErrorName returns error name.
func (SubmitJobResponseValidationError) Field ¶
func (e SubmitJobResponseValidationError) Field() string
Field function returns field value.
func (SubmitJobResponseValidationError) Key ¶
func (e SubmitJobResponseValidationError) Key() bool
Key function returns key value.
func (SubmitJobResponseValidationError) Reason ¶
func (e SubmitJobResponseValidationError) Reason() string
Reason function returns reason value.